aboutsummaryrefslogtreecommitdiffstats
path: root/apps/files_sharing/js/sharedfilelist.js
diff options
context:
space:
mode:
Diffstat (limited to 'apps/files_sharing/js/sharedfilelist.js')
-rw-r--r--apps/files_sharing/js/sharedfilelist.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/apps/files_sharing/js/sharedfilelist.js b/apps/files_sharing/js/sharedfilelist.js
index e8420113ad9..7d7e91dd965 100644
--- a/apps/files_sharing/js/sharedfilelist.js
+++ b/apps/files_sharing/js/sharedfilelist.js
@@ -17,7 +17,7 @@
* @classdesc Sharing file list.
* Contains both "shared with others" and "shared with you" modes.
*
* @param $el container element with existing markup for the #controls
* and a table
* @param [options] map of options, see other parameters
* @param {boolean} [options.sharedWithUser] true to return files shared with
@@ -158,8 +158,8 @@
var dir = this.getCurrentDirectory()
if (dir === '/') {
// root has special permissions
- this.$el.find('#emptycontent').toggleClass('hidden', !this.isEmpty)
- this.$el.find('#filestable thead th').toggleClass('hidden', this.isEmpty)
+ this.$el.find('.emptyfilelist.emptycontent').toggleClass('hidden', !this.isEmpty)
+ this.$el.find('.files-filestable thead th').toggleClass('hidden', this.isEmpty)
// hide expiration date header for non link only shares
if (!this._linksOnly) {
@@ -17,7 +17,7 @@
* Contains both "shared with others" and "shared with you" modes.
*
- * @param $el container element with existing markup for the #controls
+ * @param $el container element with existing markup for the .files-controls
* and a table
* @param [options] map of options, see other parameters